External Utils
--------------

External pure-python packages that we bundle. Developers can run
`FETCH_EXTERNAL_PACKAGES.sh` to pull the codes from their canonical source
and install them into the source tree.